Learn R Programming

GEInfo (version 1.0)

PubMed.search: Search prior counts for G variables and G-E interactions

Description

Provide an available tool for mining prior counts for G variables and G-E interactions from PubMed database.

Usage

PubMed.search(Yname, Gname, Ename, Gnamefile)

Arguments

Yname

A user supplied character including disease name such as "breast".

Gname

A user supplied character vector including all G variable names.

Ename

A user supplied character vector including all E variable names.

Gnamefile

A newline-delimited text file uploaded by users that contains all the G variable names to be searched. Each row represents a G variable name. It provides another way to input G variable names besides from argument "Gname".

Value

Return the searched frequencies.

G.count

A numeric vector, presenting the prior counts for all searched G variables.

GE.count

A numeric matrix of dimensions length(Gname) x length(Ename), which presents the prior counts for all G variables (Gname) and E variables (Ename) comparisons

Examples

Run this code
# NOT RUN {
Yname <- c('breast')
Gname <- c('CAMP')
Ename <- c('Age')
res <- PubMed.search(Yname,Gname,Ename)
res
# }

Run the code above in your browser using DataLab