Report the estimate of all coefficients from a fitted "CGEInfo" or "GEInfo" model object.
# S3 method for GEInfo
coef(object, ...)A fitted "CGEInfo" or "GEInfo" model object for which the estimate of coefficients is extracted.
Other arguments.
A coefficient vector of length (q+1) x (p+1), including the estimates for \(\alpha\) (intercept), \(a\) (coefficients for all E variables), and \(b\) (coefficients for all G variables and G-E interactions).